#!/bin/bash

cd $(dirname $(readlink -f $0))

which hadoop > /dev/null
status=$?
if test $status -ne 0 ; then
    echo ""
    echo "Hadoop is not installed in the system."
    echo "Please install Hadoop and make sure the hadoop binary is accessible."
    exit 127
fi

#help message
help()
{
    
echo "Usage: $0 [OPTIONS] [INPUT (EDGE LIST FILE)]"
echo "Enumerate triangles in a graph"
echo "  "
echo "  -p[PARTITIONS]           set the number of partitions (optional)."
echo "  -i                       vertex numbers are in [0:2^31] of range."
echo "  -R[MAPTASKS]             set the number of reduce tasks (default: 1)."
echo "  -A[Algorithm]            set the algorithm (options: base, cd, sc (default))"
echo " "
echo "Example:"
echo "  $0 -R1 -Asc -i path/to/triangle/file"
echo " "
echo " "
}

REDUCETASKS=1
COLORS=
ALGORITHM=sc
LONG=long

# Execute getopt
ARGS=$(getopt -u -o p:iR:A: -- "$@")
set -- $ARGS
while [ $# -gt 0 ]; do
  case "$1" in
    -p)
        COLORS="$2"
        shift;;
    -i)
        LONG="int"
         ;;
    -R)
        REDUCETASKS="-Dmapred.reduce.tasks=$2"
        shift;;
    -A)
        ALGORITHM="$2"
        shift;;

    (--) shift;break;;
    (-*) 
        echo "Error: invalid option $1"
        echo "========================================="
        help;
        exit 1;;
    (*) break;;
  esac
  shift
done

if [ $# -eq 0 ];then
    echo "Error: input path is not defined."
    echo "========================================="
    help
    exit 127
fi

INPUT=$1

QUERY="hadoop jar bin/pte-1.0.jar pte.PTE_"$LONG"_"$ALGORITHM" "$REDUCETASKS" -libjars bin/trove-3.0.3.jar,bin/kryo-3.0.2.jar "$INPUT" "$COLORS
echo hadoop query: $QUERY
echo =====================
$QUERY